NativeXComponent

Struct NativeXComponent 

pub struct NativeXComponent {
    pub raw: XComponentRaw,
    /* private fields */
}

Fields

raw: XComponentRaw

Implementations

Source

impl NativeXComponent

pub fn new(raw: XComponentRaw) -> Self

pub fn with_id(raw: XComponentRaw, id: String) -> Self

pub fn id(&self) -> Result<String>

Get current xcomponent instance’s id

pub fn raw(&self) -> *mut OH_NativeXComponent

get raw point

pub fn native_window(&self) -> Option<RawWindow>

pub fn register_callback(&self) -> Result<()>

Register callbacks
For multi-mode, it will use hashmap to store all of your callbacks closure.
This may cause xcomponent being slower, if you want to avoid this.
You can disable feature with callbacks and use register_native_callback

pub fn on_surface_changed<T: Fn(XComponentRaw, WindowRaw) -> Result<()> + 'static>( &self, cb: T, )

pub fn on_surface_created<T: Fn(XComponentRaw, WindowRaw) -> Result<()> + 'static>( &self, cb: T, )

pub fn on_surface_destroyed<T: Fn(XComponentRaw, WindowRaw) -> Result<()> + 'static>( &self, cb: T, )

pub fn on_touch_event<T: Fn(XComponentRaw, WindowRaw, TouchEventData) -> Result<()> + 'static>( &self, cb: T, )

pub unsafe fn register_native_callback( &self, callbacks: Box<OH_NativeXComponent_Callback>, ) -> Result<()>

Use ffi to register callbacks directly.

pub fn size(&self, window: WindowRaw) -> Result<XComponentSize>

Get current XComponent’s size info include width and height.

pub fn offset(&self, window: WindowRaw) -> Result<XComponentOffset>

pub fn set_frame_rate(&self, min: i32, max: i32, expected: i32) -> Result<()>

pub fn on_frame_callback<T: Fn(XComponentRaw, u64, u64) -> Result<()> + 'static>( &self, cb: T, ) -> Result<()>

Register frame callback

pub fn on_key_event<T: Fn(XComponentRaw, WindowRaw, KeyEventData) -> Result<()> + 'static>( &self, cb: T, ) -> Result<()>

pub fn on_hover_event<T: Fn(XComponentRaw, bool) -> Result<()> + 'static>( &self, cb: T, ) -> Result<()>

pub fn on_mouse_event<T: Fn(XComponentRaw, WindowRaw, MouseEventData) -> Result<()> + 'static>( &self, cb: T, ) -> Result<()>

pub fn register_mouse_event_callback(&self) -> Result<()>

pub fn on_ui_input_event<T: Fn(XComponentRaw, ArkUIInputEvent) -> Result<()> + 'static>( &self, cb: T, ) -> Result<()>